@@ -5,8 +5,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef AKREGATOR_CONFIG_BROWSER_H
-#define AKREGATOR_CONFIG_BROWSER_H
+#pragma once
 
 #include <KCModule>
 
@@ -25,4 +24,3 @@ private:
     QWidget *const m_widget;
 };
 
-#endif // AKREGATOR_CONFIG_BROWSER_H
