@@ -6,8 +6,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef AKREGATOR_CREATEFEEDCOMMAND_H
-#define AKREGATOR_CREATEFEEDCOMMAND_H
+#pragma once
 
 #include "command.h"
 
@@ -41,4 +40,3 @@ private:
 };
 }
 
-#endif // AKREGATOR_CREATEFEEDCOMMAND_H
