@@ -6,8 +6,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef AKREGATOR_IMPORTFEEDLISTCOMMAND_H
-#define AKREGATOR_IMPORTFEEDLISTCOMMAND_H
+#pragma once
 
 #include "command.h"
 
@@ -45,4 +44,3 @@ private:
 };
 }
 
-#endif // AKREGATOR_IMPORTFEEDLISTCOMMAND_H
