@@ -6,12 +6,11 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef AKREGATOR_UTILS_H
-#define AKREGATOR_UTILS_H
+#pragma once
 
 #include "akregator_export.h"
 #include <QString>
-typedef unsigned int uint;
+using uint = unsigned int;
 
 namespace Akregator
 {
@@ -33,4 +32,3 @@ public:
 };
 } // namespace Akregator
 
-#endif // AKREGATOR_UTILS_H
